package mhayaTime

import (
	"testing"
)

func TestMhayaTime_IsNow(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsNow())
}

func TestMhayaTime_IsFuture(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsFuture())
}

func TestMhayaTime_IsPast(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsPast())
}

func TestMhayaTime_IsLeapYear(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsLeapYear())
}

func TestMhayaTime_IsLongYear(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsLongYear())
}

func TestMhayaTime_IsJanuary(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsJanuary())
}

func TestMhayaTime_IsFebruary(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsFebruary())
}

func TestMhayaTime_IsMarch(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsMarch())
}

func TestMhayaTime_IsApril(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsApril())
}

func TestMhayaTime_IsMay(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsMay())
}

func TestMhayaTime_IsJune(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsJune())
}

func TestMhayaTime_IsJuly(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsJuly())
}

func TestMhayaTime_IsAugust(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsAugust())
}

func TestMhayaTime_IsSeptember(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsSeptember())
}

func TestMhayaTime_IsOctober(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsOctober())
}

func TestMhayaTime_IsDecember(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsDecember())
}

func TestMhayaTime_IsMonday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsMonday())
}

func TestMhayaTime_IsTuesday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsTuesday())
}

func TestMhayaTime_IsWednesday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsWednesday())
}

func TestMhayaTime_IsThursday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsThursday())
}

func TestMhayaTime_IsFriday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsFriday())
}

func TestMhayaTime_IsSaturday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsSaturday())
}

func TestMhayaTime_IsSunday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsSunday())
}

func TestMhayaTime_IsWeekday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsWeekday())
}

func TestMhayaTime_IsWeekend(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsWeekend())
}

func TestMhayaTime_IsYesterday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsYesterday())
}

func TestMhayaTime_IsYesterday1(t *testing.T) {
	now := Now()
	now.SubDay()
	t.Logf("result = %v", now.IsYesterday())
}

func TestMhayaTime_IsToday(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsToday())
}

func TestMhayaTime_IsTomorrow(t *testing.T) {
	now := Now()
	t.Logf("result = %v", now.IsTomorrow())
}
